| Portability | portable |
|---|---|
| Stability | experimental |
| Maintainer | mik@konecny.aow.cz |
Data.Number.ER.Real.Arithmetic.LinearSolver
Description
A simple validated solver for systems of linear equations with interval coefficients. It uses a naive splitting approach and is therefore very slow.
Documentation
Arguments
| :: ERIntApprox ira | |
| => [(Map VarID ira, ira)] | the equations; each equation has coefficients of linear terms + constant term |
| -> Box ira | the domain of the variables |
| -> ira | an upper bound on the size of an acceptable solution box |
| -> Maybe (Box ira) | A box containing at least one solution within the domain; Nothing if there is no solution. |